@@ -31,40 +31,40 @@ class TransferMultiSegKio : public Transfer
 
     public:
         TransferMultiSegKio(TransferGroup * parent, TransferFactory * factory,
-                    Scheduler * scheduler, const KUrl & src, const KUrl & dest,
-                    const QDomElement * e = 0);
+                    Scheduler * scheduler, const QUrl & src, const QUrl & dest,
+                    const QDomElement * e = nullptr);
 
-        bool repair(const KUrl &file = KUrl());
+        bool repair(const QUrl &file = QUrl());
 
         /**
          * Move the download to the new destination
          * @param newDirectory is a directory where the download should be stored
          * @returns true if newDestination can be used
          */
-        virtual bool setDirectory(const KUrl &newDirectory);
+        virtual bool setDirectory(const QUrl &newDirectory);
 
         virtual void init();
         virtual void deinit(Transfer::DeleteOptions options);
 
-        QHash<KUrl, QPair<bool, int> > availableMirrors(const KUrl &file) const;
-        void setAvailableMirrors(const KUrl &file, const QHash<KUrl, QPair<bool, int> > &mirrors);
+        QHash<QUrl, QPair<bool, int> > availableMirrors(const QUrl &file) const;
+        void setAvailableMirrors(const QUrl &file, const QHash<QUrl, QPair<bool, int> > &mirrors);
 
         /**
          * @param file for which to get the verifier
          * @return Verifier that allows you to add checksums manually verify a file etc.
          */
-        virtual Verifier *verifier(const KUrl &file = KUrl());
+        virtual Verifier *verifier(const QUrl &file = QUrl());
 
         /**
          * @param file for which to get the signature
          * @return Signature that allows you to add signatures and verify them
          */
-        virtual Signature *signature(const KUrl &file = KUrl());
+        virtual Signature *signature(const QUrl &file = QUrl());
 
         FileModel *fileModel();
 
     public slots:
-        bool setNewDestination(const KUrl &newDestination);
+        bool setNewDestination(const QUrl &newDestination);
         // --- Job virtual functions ---
         void start();
         void stop();
@@ -79,8 +79,8 @@ class TransferMultiSegKio : public Transfer
     private slots:
         void slotDataSourceFactoryChange(Transfer::ChangesFlags change);
         void slotUpdateCapabilities();
-        void slotSearchUrls(const QList<KUrl> &urls);
-        void slotRename(const KUrl &oldUrl, const KUrl &newUrl);
+        void slotSearchUrls(const QList<QUrl> &urls);
+        void slotRename(const QUrl &oldUrl, const QUrl &newUrl);
         void slotVerified(bool isVerified);
         void slotStatResult(KJob * kioJob);
 
